"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractQueueService = void 0;
const node_util_1 = require("node:util");
const node_core_1 = require("@lokalise/node-core");
const HandlerSpy_1 = require("./HandlerSpy");
class AbstractQueueService {
    errorReporter;
    logger;
    messageTypeField;
    messageIdField;
    logMessages;
    creationConfig;
    locatorConfig;
    deletionConfig;
    _handlerSpy;
    get handlerSpy() {
        if (!this._handlerSpy) {
            throw new Error('HandlerSpy was not instantiated, please pass `handlerSpy` parameter during queue service creation.');
        }
        return this._handlerSpy;
    }
    constructor({ errorReporter, logger }, options) {
        this.errorReporter = errorReporter;
        this.logger = logger;
        this.messageTypeField = options.messageTypeField;
        this.messageIdField = options.messageIdField ?? 'id';
        this.creationConfig = options.creationConfig;
        this.locatorConfig = options.locatorConfig;
        this.deletionConfig = options.deletionConfig;
        this.logMessages = options.logMessages ?? false;
        this._handlerSpy = (0, HandlerSpy_1.resolveHandlerSpy)(options);
    }
    /**
     * Format message for logging
     */
    resolveMessageLog(message, _messageType) {
        return message;
    }
    /**
     * Log preformatted and potentially presanitized message payload
     */
    logMessage(messageLogEntry) {
        this.logger.debug(messageLogEntry);
    }
    handleError(err, context) {
        const logObject = (0, node_core_1.resolveGlobalErrorLogObject)(err);
        if (logObject === 'string') {
            this.logger.error(context, logObject);
        }
        else if (typeof logObject === 'object') {
            this.logger.error({
                ...logObject,
                ...context,
            });
        }
        if (node_util_1.types.isNativeError(err)) {
            this.errorReporter.report({ error: err, context });
        }
    }
    handleMessageProcessed(message, processingResult, messageId) {
        if (this._handlerSpy) {
            this._handlerSpy.addProcessedMessage({
                message,
                processingResult,
            }, messageId);
        }
    }
}
exports.AbstractQueueService = AbstractQueueService;
//# sourceMappingURL=AbstractQueueService.js.map