import type { MessageProcessingResult } from '../types/MessageQueueTypes';
import type { CommonQueueOptions } from './AbstractQueueService';
export type HandlerSpyParams = {
    bufferSize?: number;
    messageIdField?: string;
};
export type SpyResult<MessagePayloadSchemas extends object> = {
    message: MessagePayloadSchemas | null;
    processingResult: MessageProcessingResult;
};
export declare function isHandlerSpy<T extends object>(value: unknown): value is HandlerSpy<T>;
export type PublicHandlerSpy<MessagePayloadSchemas extends object> = Omit<HandlerSpy<MessagePayloadSchemas>, 'addProcessedMessage'>;
type DeepPartial<T> = T extends Function ? T : T extends object ? {
    [P in keyof T]?: T[P] extends Array<infer U> ? Array<DeepPartial<U>> : T[P] extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : DeepPartial<T[P]>;
} : T;
export declare class HandlerSpy<MessagePayloadSchemas extends object> {
    name: string;
    private readonly messageBuffer;
    private readonly messageIdField;
    private readonly spyPromises;
    constructor(params?: HandlerSpyParams);
    private messageMatchesFilter;
    waitForMessageWithId<T extends MessagePayloadSchemas>(id: string, processingResult?: MessageProcessingResult): Promise<SpyResult<T>>;
    waitForMessage<T extends MessagePayloadSchemas>(fields: DeepPartial<T>, processingResult?: MessageProcessingResult): Promise<SpyResult<T>>;
    clear(): void;
    addProcessedMessage(processingResult: SpyResult<MessagePayloadSchemas>, messageId?: string): void;
}
export declare function resolveHandlerSpy<T extends object>(queueOptions: CommonQueueOptions): HandlerSpy<T> | undefined;
export {};
