"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.objectMatches = exports.shallowEqual = void 0;
const fast_equals_1 = require("fast-equals");
function shallowEqual(object1, object2) {
    if ((object1 && !object2) || (!object1 && object2)) {
        return false;
    }
    if (!object1 && !object2) {
        return true;
    }
    // eslint-disable-next-line  @typescript-eslint/no-non-null-assertion
    const keys1 = Object.keys(object1);
    // eslint-disable-next-line  @typescript-eslint/no-non-null-assertion
    const keys2 = Object.keys(object2);
    if (keys1.length !== keys2.length) {
        return false;
    }
    // eslint-disable-next-line prefer-const
    for (let key of keys1) {
        // eslint-disable-next-line  @typescript-eslint/no-non-null-assertion
        if (object1[key] !== object2[key]) {
            return false;
        }
    }
    return true;
}
exports.shallowEqual = shallowEqual;
function objectMatches(
// eslint-disable-next-line @typescript-eslint/no-explicit-any
matcher, 
// eslint-disable-next-line @typescript-eslint/no-explicit-any
validatedObject) {
    for (const key in matcher) {
        if (!Object.prototype.hasOwnProperty.call(matcher, key))
            continue;
        if (!Object.prototype.hasOwnProperty.call(validatedObject, key)) {
            return false;
        }
        if (typeof matcher[key] === 'object' && matcher[key] !== null) {
            if (typeof validatedObject[key] !== 'object' || validatedObject[key] === null) {
                return false;
            }
            // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
            if (!objectMatches(matcher[key], validatedObject[key])) {
                return false;
            }
            // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
        }
        else if (!(0, fast_equals_1.deepEqual)(matcher[key], validatedObject[key])) {
            return false;
        }
    }
    return true;
}
exports.objectMatches = objectMatches;
//# sourceMappingURL=matchUtils.js.map